@@ -1,5 +1,5 @@
 /* Arg_parser - POSIX/GNU command-line argument parser. (C version)
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you have unlimited permission to
    copy, distribute, and modify it.
@@ -24,7 +24,7 @@
 
 
 static const char * const program_name = "carg_parser";
-static const char * const program_year = "2024";
+static const char * const program_year = "2025";
 static const char * invocation_name = "carg_parser";	/* default value */
 
 
@@ -53,6 +53,7 @@ static void show_help( const char verbose )
           "  -a, --append                 example of option with no argument\n"
           "  -b, --block=<arg>            example of option with required argument\n"
           "  -c, --casual[=<arg>]         example of option with optional argument\n"
+          "  -e, --empty=<arg>            example of option with maybe empty argument\n"
           "  -o <arg>                     example of short only option\n"
           "      --orphan                 example of long only option\n"
           "  -q, --quiet                  quiet operation\n"
@@ -98,24 +99,26 @@ static void internal_error( const char * const msg )
 int main( const int argc, const char * const argv[] )
   {
   char verbose = 0;
-  const struct ap_Option options[] =
+  const ap_Option options[] =
     {
-    { 'a', "append",   ap_no    },
-    { 'b', "block",    ap_yes   },
-    { 'c', "casual",   ap_maybe },
-    { 'h', "help",     ap_no    },
-    { 'H', "hidden",   ap_no    },
-    { 'o', 0,          ap_yes   },
-    { 'q', "quiet",    ap_no    },
-    { 'u', "uncaught", ap_no    },
-    { 'v', "verbose",  ap_no    },
-    { 'V', "version",  ap_no    },
-    { 256, "orphan",   ap_no    },
-    { INT_MIN, "int-min", ap_no },
-    { INT_MAX, "int-max", ap_no },
-    {   0, 0,          ap_no    } };
+    /* code, long_name, has_arg (no/yes/maybe/yme) */
+    { 'a', "append",      ap_no  },
+    { 'b', "block",       ap_yes },
+    { 'c', "casual",      ap_maybe },
+    { 'e', "empty",       ap_yme },
+    { 'h', "help",        ap_no  },
+    { 'H', "hidden",      ap_no  },
+    { 'o', 0,             ap_yes },
+    { 'q', "quiet",       ap_no  },
+    { 'u', "uncaught",    ap_no  },
+    { 'v', "verbose",     ap_no  },
+    { 'V', "version",     ap_no  },
+    { 256, "orphan",      ap_no  },
+    { INT_MIN, "int-min", ap_no  },
+    { INT_MAX, "int-max", ap_no  },
+    { 0, 0,               ap_no  } };
 
-  struct Arg_parser parser;
+  Arg_parser parser;
   int argind;
   if( argc > 0 ) invocation_name = argv[0];
 
@@ -133,6 +136,7 @@ int main( const int argc, const char * const argv[] )
       case 'a': break;				/* example, do nothing */
       case 'b': break;				/* example, do nothing */
       case 'c': break;				/* example, do nothing */
+      case 'e': break;				/* example, do nothing */
       case 'h': show_help( verbose ); return 0;
       case 'H': break;				/* example, do nothing */
       case 'o': break;				/* example, do nothing */
@@ -154,7 +158,7 @@ int main( const int argc, const char * const argv[] )
     if( code )	/* option */
       {
       printf( "option '%s'", ap_parsed_name( &parser, argind ) );
-      if( arg[0] ) printf( " with argument '%s'", arg );
+      if( arg[0] || code == 'e' ) printf( " with argument '%s'", arg );
       if( code == INT_MIN || code == INT_MAX ) printf( " (code 0x%X)", code );
       }
     else	/* non-option */
