@@ -1,5 +1,5 @@
 /* Arg_parser - POSIX/GNU command-line argument parser. (C++ version)
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you have unlimited permission to
    copy, distribute, and modify it.
@@ -28,7 +28,7 @@
 namespace {
 
 const char * const program_name = "arg_parser";
-const char * const program_year = "2024";
+const char * const program_year = "2025";
 const char * invocation_name = program_name;		// default value
 
 
@@ -57,6 +57,7 @@ void show_help( const bool verbose )
                "  -a, --append                 example of option with no argument\n"
                "  -b, --block=<arg>            example of option with required argument\n"
                "  -c, --casual[=<arg>]         example of option with optional argument\n"
+               "  -e, --empty=<arg>            example of option with maybe empty argument\n"
                "  -o <arg>                     example of short only option\n"
                "      --orphan                 example of long only option\n"
                "  -q, --quiet                  quiet operation\n"
@@ -108,20 +109,22 @@ int main( const int argc, const char * const argv[] )
 
   const Arg_parser::Option options[] =
     {
-    { 'a', "append",   Arg_parser::no    },
-    { 'b', "block",    Arg_parser::yes   },
-    { 'c', "casual",   Arg_parser::maybe },
-    { 'h', "help",     Arg_parser::no    },
-    { 'H', "hidden",   Arg_parser::no    },
-    { 'o', 0,          Arg_parser::yes   },
-    { 'q', "quiet",    Arg_parser::no    },
-    { 'u', "uncaught", Arg_parser::no    },
-    { 'v', "verbose",  Arg_parser::no    },
-    { 'V', "version",  Arg_parser::no    },
-    { 256, "orphan",   Arg_parser::no    },
-    { INT_MIN, "int-min", Arg_parser::no },
-    { INT_MAX, "int-max", Arg_parser::no },
-    {   0, 0,          Arg_parser::no    } };
+    // code, long_name, has_arg (no/yes/maybe/yme)
+    { 'a', "append",      Arg_parser::no  },
+    { 'b', "block",       Arg_parser::yes },
+    { 'c', "casual",      Arg_parser::maybe },
+    { 'e', "empty",       Arg_parser::yme },
+    { 'h', "help",        Arg_parser::no  },
+    { 'H', "hidden",      Arg_parser::no  },
+    { 'o', 0,             Arg_parser::yes },
+    { 'q', "quiet",       Arg_parser::no  },
+    { 'u', "uncaught",    Arg_parser::no  },
+    { 'v', "verbose",     Arg_parser::no  },
+    { 'V', "version",     Arg_parser::no  },
+    { 256, "orphan",      Arg_parser::no  },
+    { INT_MIN, "int-min", Arg_parser::no  },
+    { INT_MAX, "int-max", Arg_parser::no  },
+    { 0, 0,               Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
@@ -136,6 +139,7 @@ int main( const int argc, const char * const argv[] )
       case 'a': break;				// example, do nothing
       case 'b': break;				// example, do nothing
       case 'c': break;				// example, do nothing
+      case 'e': break;				// example, do nothing
       case 'h': show_help( verbose ); return 0;
       case 'H': break;				// example, do nothing
       case 'o': break;				// example, do nothing
@@ -157,7 +161,7 @@ int main( const int argc, const char * const argv[] )
     if( code )	// option
       {
       std::printf( "option '%s'", parser.parsed_name( argind ).c_str() );
-      if( arg[0] ) std::printf( " with argument '%s'", arg );
+      if( arg[0] || code == 'e' ) std::printf( " with argument '%s'", arg );
       if( code == INT_MIN || code == INT_MAX ) std::printf( " (code 0x%X)", code );
       }
     else	// non-option
