@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Arg_parser - POSIX/GNU command-line argument parser.
-# Copyright (C) 2011-2024 Antonio Diaz Diaz.
+# Copyright (C) 2011-2025 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -33,28 +33,32 @@ test_failed() { fail=1 ; printf "\n$1" ; [ -z "$2" ] || printf "($2)" ; }
 printf "testing arg_parser-%s..." "$2"
 
 for i in "${PARSER}" "${CPARSER}" ; do
-	"$i" -h > /dev/null || test_failed $LINENO "$i"
-	"$i" --help > /dev/null || test_failed $LINENO "$i"
-	"$i" -V > /dev/null || test_failed $LINENO "$i"
-	"$i" --version > /dev/null || test_failed $LINENO "$i"
-	"$i" -h -v > /dev/null || test_failed $LINENO "$i"
-	"$i" -v -h > /dev/null || test_failed $LINENO "$i"
+  "$i" -h > /dev/null || test_failed $LINENO "$i"
+  "$i" --help > /dev/null || test_failed $LINENO "$i"
+  "$i" -V > /dev/null || test_failed $LINENO "$i"
+  "$i" --version > /dev/null || test_failed $LINENO "$i"
+  "$i" -h -v > /dev/null || test_failed $LINENO "$i"
+  "$i" -v -h > /dev/null || test_failed $LINENO "$i"
 
-	"$i" --append -a -b 5 --block 10 -c -carg --casual --casual=arg -o file --orphan --verbose file1 file2 > out ||
-		test_failed $LINENO "$i"
-	cmp "${in}" out || test_failed $LINENO "$i"
+  "$i" --append -a -b 5 --block 10 -c -carg --casual= --casual=arg -e "" \
+       -earg --empty= --emp=arg -o file --orphan --verbose file1 file2 > out ||
+    test_failed $LINENO "$i"
+  cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" file1 file2 --append -ab5 --block=10 -c -carg --casua --casua=arg -ofile --orpha --verbos > out ||
-		test_failed $LINENO "$i"
-	cmp "${in}" out || test_failed $LINENO "$i"
+  "$i" file1 file2 --append -ab5 --block=10 -c -carg --casu --casu=arg -e "" \
+       -earg --empty="" --empty=arg -ofile --orpha --verbos > out ||
+    test_failed $LINENO "$i"
+  cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" --append -a file1 -b 5 --block 10 -c -carg --casu --casu=arg -o file file2 --orph --verbo > out ||
-		test_failed $LINENO "$i"
-	cmp "${in}" out || test_failed $LINENO "$i"
+  "$i" --append -a file1 -b 5 --block 10 -c -carg --casual --casua=arg -e "" \
+       -e arg --empty "" --empty arg -o file file2 --orph --verbo > out ||
+    test_failed $LINENO "$i"
+  cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" --append -a -b5 --block=10 -c -carg --cas= file1 --cas=arg -ofile --orp --verb file2 > out ||
-		test_failed $LINENO "$i"
-	cmp "${in}" out || test_failed $LINENO "$i"
+  "$i" --append -a -b5 --block=10 -c -carg --cas= --cas=arg -e "" file1 \
+       -e arg --emp "" --emp arg -ofile --orp --verb file2 > out ||
+    test_failed $LINENO "$i"
+  cmp "${in}" out || test_failed $LINENO "$i"
 done
 
 "${PARSER}" --int-min --int-max > out || test_failed $LINENO
@@ -91,6 +95,9 @@ for i in "${PARSER}" "${CPARSER}" ; do
 	"$i" --block= 2> /dev/null
 	[ $? = 1 ] || test_failed $LINENO "$i"
 
+	"$i" -e"" 2> /dev/null
+	[ $? = 1 ] || test_failed $LINENO "$i"
+
 	"$i" -u 2> /dev/null				# uncaught option
 	[ $? = 3 ] || test_failed $LINENO "$i"
 done
